@@ -9,7 +9,8 @@ void BI_BlacsWarn(int ConTxt, int line, char *file, char *form, ...)
    char cline[100];
 
    va_start(argptr, form);
-   vsprintf(cline, form, argptr);
+   //WCC vsprintf(cline, form, argptr);
+   snprintf(cline, 100, form, argptr);
    va_end(argptr);
 
    if (ConTxt > -1)
