@@ -8,10 +8,17 @@
 void Cdgamx2d(int ConTxt, char *scope, char *top, int m, int n, double *A,
               int lda, int *rA, int *cA, int ldia, int rdest, int cdest)
 #else
+#ifdef FC_LEN_T
+F_VOID_FUNC dgamx2d_(int *ConTxt, F_CHAR scope, F_CHAR top, int *m, int *n,
+                     double *A, int *lda, int *rA, int *cA, int *ldia,
+                     int *rdest, int *cdest,
+                     FC_LEN_T scope_len, FC_LEN_T top_len)
+#else
 F_VOID_FUNC dgamx2d_(int *ConTxt, F_CHAR scope, F_CHAR top, int *m, int *n,
                      double *A, int *lda, int *rA, int *cA, int *ldia,
                      int *rdest, int *cdest)
 #endif
+#endif
 /*
  *  -- V1.1 BLACS routine --
  *  University of Tennessee, May 1, 1996
@@ -201,7 +208,8 @@ F_VOID_FUNC dgamx2d_(int *ConTxt, F_CHAR scope, F_CHAR top, int *m, int *n,
       bp = BI_GetBuff(i);
       bp2 = &BI_AuxBuff;
       bp2->Buff = &bp->Buff[length];
-      BI_dmvcopy(Mpval(m), Mpval(n), A, tlda, bp->Buff);
+      /*WCC BI_dmvcopy(Mpval(m), Mpval(n), A, tlda, bp->Buff); */
+      BI_dmvcopy(Mpval(m), Mpval(n), A, tlda, (double*) bp->Buff);
 /*
  *    Fill in distance vector
  */
@@ -259,7 +267,8 @@ F_VOID_FUNC dgamx2d_(int *ConTxt, F_CHAR scope, F_CHAR top, int *m, int *n,
          bp = BI_GetBuff(length*2);
          bp2 = &BI_AuxBuff;
          bp2->Buff = &bp->Buff[length];
-         BI_dmvcopy(Mpval(m), Mpval(n), A, tlda, bp->Buff);
+         /*WCC BI_dmvcopy(Mpval(m), Mpval(n), A, tlda, bp->Buff); */
+         BI_dmvcopy(Mpval(m), Mpval(n), A, tlda, (double*) bp->Buff);
       }
       bp->N = bp2->N = N;
       bp->dtype = bp2->dtype = MPI_DOUBLE;
@@ -289,7 +298,8 @@ F_VOID_FUNC dgamx2d_(int *ConTxt, F_CHAR scope, F_CHAR top, int *m, int *n,
 	 	       ctxt->scp->comm);
          if (ctxt->scp->Iam == dest)
 	 {
-	    BI_dvmcopy(Mpval(m), Mpval(n), A, tlda, bp2->Buff);
+	    /*WCC BI_dvmcopy(Mpval(m), Mpval(n), A, tlda, bp2->Buff); */
+	    BI_dvmcopy(Mpval(m), Mpval(n), A, tlda, (double*) bp2->Buff);
 	    if (Mpval(ldia) != -1)
                BI_TransDist(ctxt, tscope, Mpval(m), Mpval(n), rA, cA, tldia,
                             (BI_DistType *) &bp2->Buff[idist],
@@ -300,7 +310,8 @@ F_VOID_FUNC dgamx2d_(int *ConTxt, F_CHAR scope, F_CHAR top, int *m, int *n,
       {
          ierr=MPI_Allreduce(bp->Buff, bp2->Buff, bp->N, bp->dtype, BlacComb,
 		          ctxt->scp->comm);
-	 BI_dvmcopy(Mpval(m), Mpval(n), A, tlda, bp2->Buff);
+	 /*WCC BI_dvmcopy(Mpval(m), Mpval(n), A, tlda, bp2->Buff); */
+	 BI_dvmcopy(Mpval(m), Mpval(n), A, tlda, (double*) bp2->Buff);
          if (Mpval(ldia) != -1)
             BI_TransDist(ctxt, tscope, Mpval(m), Mpval(n), rA, cA, tldia,
                          (BI_DistType *) &bp2->Buff[idist],
@@ -379,6 +390,7 @@ F_VOID_FUNC dgamx2d_(int *ConTxt, F_CHAR scope, F_CHAR top, int *m, int *n,
 /*
  *    Unpack the amx array
  */
-      if (bp != &BI_AuxBuff) BI_dvmcopy(Mpval(m), Mpval(n), A, tlda, bp->Buff);
+      /*WCC if (bp != &BI_AuxBuff) BI_dvmcopy(Mpval(m), Mpval(n), A, tlda, bp->Buff); */
+      if (bp != &BI_AuxBuff) BI_dvmcopy(Mpval(m), Mpval(n), A, tlda, (double*) bp->Buff);
    }
 }
